## cdist-type__apt_key_uri(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__apt_key_uri - add apt key from uri

## 2. DESCRIPTION

Download a key from an uri and add it to the apt keyring.

## 3. REQUIRED PARAMETERS

uri
  the uri from which to download the key

## 4. OPTIONAL PARAMETERS

state
  present or absent, defaults to present
name
  a name for this key, used when testing if it is already installed. Defaults to __object_id

## 5. EXAMPLES

    __apt_key_uri rabbitmq \
       --name 'RabbitMQ Release Signing Key <info@rabbitmq.com>' \
       --uri http://www.rabbitmq.com/rabbitmq-signing-key-public.asc \
       --state present

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011-2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).